==> kubernetes-model-0.1.3-sources.jar: io/fabric8/kubernetes/api/model/HTTPGetActionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class HTTPGetActionBuilder extends HTTPGetActionFluent<HTTPGetActionBuilder> implements VisitableBuilder<HTTPGetAction,HTTPGetActionBuilder>{

     HTTPGetActionFluent<?> fluent;
public HTTPGetActionBuilder(){
    this(new HTTPGetAction());
}
public HTTPGetActionBuilder( HTTPGetActionFluent<?> fluent ){
    this(fluent, new HTTPGetAction());
}
public HTTPGetActionBuilder( HTTPGetActionFluent<?> fluent , HTTPGetAction instance ){
    this.fluent = fluent; fluent.withHost(instance.getHost()); fluent.withPath(instance.getPath()); fluent.withPort(instance.getPort()); 
}
public HTTPGetActionBuilder( HTTPGetAction instance ){
    this.fluent = this; this.withHost(instance.getHost()); this.withPath(instance.getPath()); this.withPort(instance.getPort()); 
}

public EditableHTTPGetAction build(){
    EditableHTTPGetAction buildable = new EditableHTTPGetAction(fluent.getHost(),fluent.getPath(),fluent.getPort());
validate(buildable);
return buildable;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.16-sources.jar: io/fabric8/kubernetes/api/model/HTTPGetActionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class HTTPGetActionBuilder extends HTTPGetActionFluent<HTTPGetActionBuilder> implements VisitableBuilder<HTTPGetAction,HTTPGetActionBuilder>{

     HTTPGetActionFluent<?> fluent;
public HTTPGetActionBuilder(){
    this(new HTTPGetAction());
}
public HTTPGetActionBuilder( HTTPGetActionFluent<?> fluent ){
    this(fluent, new HTTPGetAction());
}
public HTTPGetActionBuilder( HTTPGetActionFluent<?> fluent , HTTPGetAction instance ){
    this.fluent = fluent; fluent.withHost(instance.getHost()); fluent.withPath(instance.getPath()); fluent.withPort(instance.getPort()); fluent.withScheme(instance.getScheme()); 
}
public HTTPGetActionBuilder( HTTPGetAction instance ){
    this.fluent = this; this.withHost(instance.getHost()); this.withPath(instance.getPath()); this.withPort(instance.getPort()); this.withScheme(instance.getScheme()); 
}

public EditableHTTPGetAction build(){
    EditableHTTPGetAction buildable = new EditableHTTPGetAction(fluent.getHost(),fluent.getPath(),fluent.getPort(),fluent.getScheme());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
HTTPGetActionBuilder that = (HTTPGetActionBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
